@@ -10,6 +10,7 @@ class AmountLicensingCollabResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     licensing_collab_id = fields.Integer(required=True)
-    value = fields.Decimal(required=True)
+    deal_value = fields.Decimal(required=True)
+    currency = fields.String(required=True)
     type = fields.String(required=True)
     updated_at = fields.DateTime()
