@@ -5,6 +5,7 @@ from sqlalchemy import (
     DateTime,
     ForeignKey,
     Boolean,
+    Float,
 )
 from datetime import datetime
 
@@ -32,7 +33,9 @@ class CompanyFilingModel(Base):
     )
     date = Column(DateTime, nullable=True)
     title = Column(String(255), nullable=True)
+    old_type = Column(String(255), nullable=True)
     type = Column(String(255), nullable=True)
+    type_score = Column(Float, nullable=True)
     orig_file_url = Column(String(255), nullable=True)
     is_deleted = Column(Boolean, nullable=True)
     unprocessed = Column(Boolean, nullable=True)
