@@ -32,9 +32,9 @@ class DocTextModel(Base):
         ForeignKey('company_filings.id'),
         nullable=True,
     )
-    company_scientific_link_id = Column(
+    scientific_link_id = Column(
         Integer,
-        ForeignKey('company_scientific_links.id'),
+        ForeignKey('scientific_links.id'),
         nullable=True,
     )
     pubmed_id = Column(
