@@ -21,20 +21,6 @@ class InterventionDataModel(Base):
         nullable=False
     )
     date = Column(DateTime, nullable=True)
-    intervention_id = Column(
-        Integer,
-        ForeignKey('interventions.id'),
-        nullable=False,
-    )
-    stage = Column(
-        Integer,
-        nullable=True,
-    )
-    condition_id = Column(
-        Integer,
-        ForeignKey('conditions.id'),
-        nullable=True,
-    )
     news_id = Column(
         Integer,
         ForeignKey('newswires.id'),
