@@ -18,7 +18,7 @@ class LatestPipelineProductResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['latest_catalyst_date']
 
         in_data = pre_load_date_fields(
@@ -40,7 +40,7 @@ class LatestPipelinePatchSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['latest_catalyst_date']
 
         in_data = pre_load_date_fields(
