@@ -6,7 +6,6 @@ from sqlalchemy import (
     String,
     DateTime,
     ForeignKey,
-    Float,
     DECIMAL
 )
 
@@ -17,6 +16,8 @@ class MergerModel(Base):
     __tablename__ = "mergers"
 
     id = Column(Integer, primary_key=True)
+    announcement_date = Column(DateTime, nullable=False)
+    news_id = Column(Integer, ForeignKey('newswires.id'), nullable=False)
     target_sec_id = Column(Integer, ForeignKey('companies_sec.id'),
                            nullable=True)
     target_ous_id = Column(Integer, ForeignKey('companies_ous.id'),
@@ -26,10 +27,8 @@ class MergerModel(Base):
     acquirer_ous_id = Column(Integer, ForeignKey('companies_ous.id'),
                              nullable=True)
     deal_value = Column(DECIMAL(13, 2), nullable=True)
-    type = Column(String(50), nullable=True)
-    announcement_date = Column(DateTime, nullable=False)
-    offer_price = Column(Float, nullable=True)
-    market_price = Column(Float, nullable=True)
+    currency = Column(String(20), nullable=True)
+    offer_price = Column(String(100), nullable=True)
     dma_file_id = Column(Integer, ForeignKey('files.id'), nullable=True)
     updated_at = Column(
         DateTime,
