@@ -3,11 +3,10 @@ from datetime import datetime
 from sqlalchemy import (
     Column,
     Integer,
-    String,
     DateTime,
     ForeignKey,
-    Float,
-    DECIMAL
+    Text,
+    Boolean,
 )
 
 from ...database import Base
@@ -19,17 +18,12 @@ class MergerOutboxModel(Base):
     id = Column(Integer, primary_key=True)
     announcement_date = Column(DateTime, nullable=False)
     news_id = Column(Integer, ForeignKey('newswires.id'), nullable=False)
-    target_sec_id = Column(Integer, ForeignKey('companies_sec.id'),
-                           nullable=True)
-    target_ous_id = Column(Integer, ForeignKey('companies_ous.id'),
-                           nullable=True)
-    acquirer_sec_id = Column(Integer, ForeignKey('companies_sec.id'),
-                             nullable=True)
-    acquirer_ous_id = Column(Integer, ForeignKey('companies_ous.id'),
-                             nullable=True)
-    deal_value = Column(DECIMAL(13, 2), nullable=True)
-    type = Column(String(50), nullable=True)
-    offer_price = Column(Float, nullable=True)
+    deal_value = Column(Text, nullable=True)
+    price = Column(Text, nullable=True)
+    advisors = Column(Text, nullable=True)
+    counsels = Column(Text, nullable=True)
+    sentences = Column(Text, nullable=True)
+    reviewed = Column(Boolean, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
