@@ -2,6 +2,7 @@ from sqlalchemy import (
     Column,
     Integer,
     DateTime,
+    String,
 )
 from datetime import datetime
 
@@ -17,6 +18,7 @@ class NewswireIPOOutboxModel(Base):
         nullable=False,
         index=True,
     )
+    type = Column(String(50), nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
